==> play-by-play-extract-1.0.8.tgz: package/game.service.js <==
var request = require('request');
var cheerio = require('cheerio');
var decode = require('decode-html');

var driveDetailsPattern = /(\d+) \w+, (\d+) \w+, (\d{1,2}:\d{2})/;
var playDescriptionPattern = /^(\d\w{2}) and (\S+) at (\w+ \d+)$/;
var playOutcomePattern = /^\((\d{1,2}:\d{2}) - (\d{1}\w{2})\) (.+)$/;
var playYardsPattern = /(\d+) y(ar)?d/;

exports.getGameData = function(url, callback) {

    var game = {
        homeTeam: '',
        awayTeam: '',
        homeScore: '',
        awayScore: '',
        drives: []
    };

    request(url, function(error, response, html) {
        if (!error) {
            var $ = cheerio.load(html);

            var awayTeam = getTeamData($, '.team.away');
            game.awayTeam = awayTeam.name;
            game.awayScore = awayTeam.score;
            game.awayLogo = awayTeam.logo;

            var homeTeam = getTeamData($, '.team.home');
            game.homeTeam = homeTeam.name;
            game.homeScore = homeTeam.score;
            game.homeLogo = homeTeam.homeLogo;

            populateDriveData($, game);

            callback(game);
        } else {
            console.log(error);
        }
    });
};

var getTeamData = function($, selector) {
    var data = {};

    $(selector).filter(function() {
        var gameData = $(this);
        var name = gameData.find('.long-name').html();
        var score = gameData.find('.score').html();

        data.name = name;
        data.score = score;
        data.logo = gameData.find('.team-logo').attr('src');
    });

    return data;
};

var populateDriveData = function($, game) {
    $('#gamepackage-drives-wrap ul.css-accordion li.accordion-item').each(function(index) {
        var driveData = $(this);

        var driveSummary = driveData.find('.drives').first();
        var team = driveData.has('.team-logo').attr('src') == game.homeLogo ? game.homeTeam : game.awayTeam;
        var result = decode(driveSummary.children('.headline').first().html() || '').trim();

        var details = decode(driveSummary.children('.drive-details').first().html() || '').trim();
        var detailsCapture = driveDetailsPattern.exec(details);

        var drive = {
            index: index,
            team: team,
            result: result,
            playCount: detailsCapture ? detailsCapture[1] : '',
            yards: detailsCapture ? detailsCapture[2] : '',
            time: detailsCapture ? detailsCapture[3] : '',
            plays: []
        };

        populatePlayData($, driveData, drive);

        game.drives.push(drive);
    });
};

var populatePlayData = function($, driveData, drive) {
    var plays = driveData.find('ul.drive-list li');
    plays.each(function(index) {
        var playData = $(this);

        var description = decode(playData.children('h3').html()).trim();
        var descriptionCapture = playDescriptionPattern.exec(description);

        var outcome = decode(playData.find('.post-play').html()).trim();
        var outcomeCapture = playOutcomePattern.exec(outcome);

        var down = descriptionCapture ? descriptionCapture[1] : '';
        var distance = descriptionCapture ? descriptionCapture[2] : '';
        var location = descriptionCapture ? descriptionCapture[3] : '';
        var time = outcomeCapture ? outcomeCapture[1] : '';
        var quarter = outcomeCapture ? outcomeCapture[2] : '';
        var result = outcomeCapture ? outcomeCapture[3] : '';

        var yardsCapture = result ? playYardsPattern.exec(result) : '';
        var yards = yardsCapture ? yardsCapture[1] : 0;

        yards *= yardsCapture && yardsCapture[2] ? -1 : 1;

        if (down || distance || location || time || quarter || result) {
            drive.plays.push({
                index: index,
                down: down,
                distance: distance,
                location: location,
                time: time,
                quarter: quarter,
                result: result,
                yards: yards,
                offenseFormation: {
                    name: '',
                    RB: 0,
                    TE: 0,
                    WR: 0,
                    RPS: 0
                },
                defenseFormation: {
                    name: '',
                    rush: 'N/A',
                    DL: 0,
                    LB: 0,
                    DB: 0,
                    pressure: 0,
                    pressureType: '',
                    coverage: 0,
                    tackling: 0,
                    RPS: 0
                },
                type: '',
                play: '',
                player: '',
                players: []
            });
        }
    });
};

==> play-by-play-extract-1.0.9.tgz: package/game.service.js <==
var request = require('request');
var cheerio = require('cheerio');
var decode = require('decode-html');

var driveDetailsPattern = /(\d+) \w+, (\d+) \w+, (\d{1,2}:\d{2})/;
var playDescriptionPattern = /^(\d\w{2}) and (\S+) at (\w+ \d+)$/;
var playOutcomePattern = /^\((\d{1,2}:\d{2}) - (\d{1}\w{2})\) (.+)$/;
var playYardsPattern = /(\d+) y(ar)?d/;

exports.getGameData = function(url, callback) {

    var game = {
        homeTeam: '',
        awayTeam: '',
        homeScore: '',
        awayScore: '',
        homeLogo: '',
        awayLogo: '',
        drives: []
    };

    request(url, function(error, response, html) {
        if (!error) {
            var $ = cheerio.load(html);

            var awayTeam = getTeamData($, '.team.away');
            game.awayTeam = awayTeam.name;
            game.awayScore = awayTeam.score;
            game.awayLogo = awayTeam.logo;

            var homeTeam = getTeamData($, '.team.home');
            game.homeTeam = homeTeam.name;
            game.homeScore = homeTeam.score;
            game.homeLogo = homeTeam.logo;

            populateDriveData($, game);

            callback(game);
        } else {
            console.log(error);
        }
    });
};

var getTeamData = function($, selector) {
    var data = {};

    $(selector).filter(function() {
        var gameData = $(this);
        var name = gameData.find('.long-name').html();
        var score = gameData.find('.score').html();

        data.name = name;
        data.score = score;
        data.logo = gameData.find('.team-logo').attr('src');
    });

    return data;
};

var populateDriveData = function($, game) {
    $('#gamepackage-drives-wrap ul.css-accordion li.accordion-item').each(function(index) {
        var driveData = $(this);

        var driveSummary = driveData.find('.drives').first();
        var team = driveData.find('.team-logo').attr('src') == game.homeLogo ? game.homeTeam : game.awayTeam;
        var result = decode(driveSummary.children('.headline').first().html() || '').trim();

        var details = decode(driveSummary.children('.drive-details').first().html() || '').trim();
        var detailsCapture = driveDetailsPattern.exec(details);

        var drive = {
            index: index,
            team: team,
            result: result,
            playCount: detailsCapture ? detailsCapture[1] : '',
            yards: detailsCapture ? detailsCapture[2] : '',
            time: detailsCapture ? detailsCapture[3] : '',
            plays: []
        };

        populatePlayData($, driveData, drive);

        game.drives.push(drive);
    });
};

var populatePlayData = function($, driveData, drive) {
    var plays = driveData.find('ul.drive-list li');
    plays.each(function(index) {
        var playData = $(this);

        var description = decode(playData.children('h3').html()).trim();
        var descriptionCapture = playDescriptionPattern.exec(description);

        var outcome = decode(playData.find('.post-play').html()).trim();
        var outcomeCapture = playOutcomePattern.exec(outcome);

        var down = descriptionCapture ? descriptionCapture[1] : '';
        var distance = descriptionCapture ? descriptionCapture[2] : '';
        var location = descriptionCapture ? descriptionCapture[3] : '';
        var time = outcomeCapture ? outcomeCapture[1] : '';
        var quarter = outcomeCapture ? outcomeCapture[2] : '';
        var result = outcomeCapture ? outcomeCapture[3] : '';

        var yardsCapture = result ? playYardsPattern.exec(result) : '';
        var yards = yardsCapture ? yardsCapture[1] : 0;

        yards *= yardsCapture && yardsCapture[2] ? -1 : 1;

        if (down || distance || location || time || quarter || result) {
            drive.plays.push({
                index: index,
                down: down,
                distance: distance,
                location: location,
                time: time,
                quarter: quarter,
                result: result,
                yards: yards,
                offenseFormation: {
                    name: '',
                    RB: 0,
                    TE: 0,
                    WR: 0,
                    RPS: 0
                },
                defenseFormation: {
                    name: '',
                    rush: 'N/A',
                    DL: 0,
                    LB: 0,
                    DB: 0,
                    pressure: 0,
                    pressureType: '',
                    coverage: 0,
                    tackling: 0,
                    RPS: 0
                },
                type: '',
                play: '',
                player: '',
                players: []
            });
        }
    });
};
